@@ -32,9 +32,9 @@ focal = cf.Frame2D(name='focal', axes_order=(0, 1), unit=(u.m, u.m))
 spec = cf.SpectralFrame(name='wave', unit=[u.m, ], axes_order=(2, ), axes_names=('lambda', ))
 time = cf.TemporalFrame(name='time', unit=[u.s, ], axes_order=(3, ), axes_names=('time', ), reference_frame=Time("2020-01-01"))
 
-pipe = [(detector, m1),
-        (focal, m2),
-        (icrs, None)
+pipe = [wcs.Step(detector, m1),
+        wcs.Step(focal, m2),
+        wcs.Step(icrs, None)
         ]
 
 # Create some data.
@@ -75,15 +75,19 @@ def test_init_no_transform():
     gw = wcs.WCS(output_frame='icrs')
     assert len(gw._pipeline) == 2
     assert gw.pipeline[0].frame == "detector"
-    assert gw.pipeline[0][0] == "detector"
+    with pytest.warns(DeprecationWarning, match="Indexing a WCS.pipeline step is deprecated."):
+        assert gw.pipeline[0][0] == "detector"
     assert gw.pipeline[1].frame == "icrs"
-    assert gw.pipeline[1][0] == "icrs"
+    with pytest.warns(DeprecationWarning, match="Indexing a WCS.pipeline step is deprecated."):
+        assert gw.pipeline[1][0] == "icrs"
     assert np.in1d(gw.available_frames, ['detector', 'icrs']).all()
     gw = wcs.WCS(output_frame=icrs, input_frame=detector)
     assert gw._pipeline[0].frame == "detector"
-    assert gw._pipeline[0][0] == "detector"
+    with pytest.warns(DeprecationWarning, match="Indexing a WCS.pipeline step is deprecated."):
+        assert gw._pipeline[0][0] == "detector"
     assert gw._pipeline[1].frame == "icrs"
-    assert gw._pipeline[1][0] == "icrs"
+    with pytest.warns(DeprecationWarning, match="Indexing a WCS.pipeline step is deprecated."):
+        assert gw._pipeline[1][0] == "icrs"
     assert np.in1d(gw.available_frames, ['detector', 'icrs']).all()
     with pytest.raises(NotImplementedError):
         gw(1, 2)
@@ -154,7 +158,7 @@ def test_get_transform():
     x, y = 1, 2
     fx, fy = tr_forward(1, 2)
     assert_allclose(w.pipeline[0].transform(x, y), (fx, fy))
-    assert_allclose(w.pipeline[0][1](x, y), (fx, fy))
+    assert_allclose(w.pipeline[0].transform(x, y), (fx, fy))
     assert_allclose((x, y), tr_back(*w(x, y)))
     assert(w.get_transform('detector', 'detector') is None)
 
@@ -368,9 +372,14 @@ def test_grid_from_bounding_box_step():
 def test_wcs_from_points():
     np.random.seed(0)
     hdr = fits.Header.fromtextfile(get_pkg_data_filename("data/acs.hdr"), endcard=False)
-    with warnings.catch_warnings() as w:
-        warnings.simplefilter("ignore")
+    with pytest.warns(astwcs.FITSFixedWarning) as caught_warnings:
+        # this raises a warning unimportant for this testing the pix2world
+        #   FITSFixedWarning(u'The WCS transformation has more axes (2) than
+        #        the image it is associated with (0)')
+        #   FITSFixedWarning: 'datfix' made the change
+        #       'Set MJD-OBS to 53436.000000 from DATE-OBS'. [astropy.wcs.wcs]
         w = astwcs.WCS(hdr)
+        assert len(caught_warnings) == 2
     y, x = np.mgrid[:2046:20j, :4023:10j]
     ra, dec = w.wcs_pix2world(x, y, 1)
     fiducial = coord.SkyCoord(ra.mean()*u.deg, dec.mean()*u.deg, frame="icrs")
@@ -517,7 +526,14 @@ def test_high_level_api():
 class TestImaging(object):
     def setup_class(self):
         hdr = fits.Header.fromtextfile(get_pkg_data_filename("data/acs.hdr"), endcard=False)
-        self.fitsw = astwcs.WCS(hdr)
+        with pytest.warns(astwcs.FITSFixedWarning) as caught_warnings:
+            # this raises a warning unimportant for this testing the pix2world
+            #   FITSFixedWarning(u'The WCS transformation has more axes (2) than
+            #        the image it is associated with (0)')
+            #   FITSFixedWarning: 'datfix' made the change
+            #       'Set MJD-OBS to 53436.000000 from DATE-OBS'. [astropy.wcs.wcs]
+            self.fitsw = astwcs.WCS(hdr)
+            assert len(caught_warnings) == 2
         a_coeff = hdr['A_*']
         a_order = a_coeff.pop('A_ORDER')
         b_coeff = hdr['B_*']
@@ -544,9 +560,9 @@ class TestImaging(object):
         sky_cs = cf.CelestialFrame(reference_frame=coord.ICRS(), name='sky')
         det = cf.Frame2D(name='detector')
         wcs_forward = wcslin | tan | n2c
-        pipeline = [('detector', distortion),
-                    ('focal', wcs_forward),
-                    (sky_cs, None)
+        pipeline = [wcs.Step('detector', distortion),
+                    wcs.Step('focal', wcs_forward),
+                    wcs.Step(sky_cs, None)
                     ]
 
         self.wcs = wcs.WCS(input_frame=det,
@@ -555,7 +571,6 @@ class TestImaging(object):
 
         self.xv, self.yv = xv, yv
 
-    @pytest.mark.filterwarnings('ignore')
     def test_distortion(self):
         sipx, sipy = self.fitsw.sip_pix2foc(self.xv, self.yv, 1)
         sipx = np.array(sipx) + 2048
@@ -759,7 +774,11 @@ def test_to_fits_sip_composite_frame_keep_axis(gwcs_cube_with_separable_spectral
     assert fw_hdr[f'CTYPE{ra_axis}'] == 'RA---TAN'
     assert fw_hdr['WCSAXES'] == 2
 
-    fw = astwcs.WCS(fw_hdr)
+    with pytest.warns(astwcs.FITSFixedWarning, match='The WCS transformation has more axes'):
+        # this raises a warning unimportant for this testing the pix2world
+        #   FITSFixedWarning(u'The WCS transformation has more axes (3) than
+        #        the image it is associated with (2)')
+        fw = astwcs.WCS(fw_hdr)
     gskyval = w(1, 45, 55)[1:]
     assert np.allclose(gskyval, fw.all_pix2world([[1, 45, 55]], 0)[0][1:])
 
@@ -805,8 +824,7 @@ def test_to_fits_tab_cube(gwcs_3d_galactic_spectral):
     assert np.allclose(w(x, y, z), fits_wcs_user_bb.wcs_pix2world(x, y, z, 0),
                        rtol=1e-6, atol=1e-7)
 
-
-@pytest.mark.skip(reason="Fails round-trip for -TAB axis 5")
+@pytest.mark.filterwarnings('ignore:.*The WCS transformation has more axes.*')
 def test_to_fits_tab_7d(gwcs_7d_complex_mapping):
     # gWCS:
     w = gwcs_7d_complex_mapping
@@ -874,7 +892,11 @@ def test_to_fits_no_sip_used(gwcs_spec_cel_time_4d):
     w = gwcs_spec_cel_time_4d
 
     # create FITS headers and -TAB headers
-    hdr, _ = w.to_fits(degree=3)
+    with pytest.warns(UserWarning, match='SIP distortion is not supported when the number'):
+        # UserWarning: SIP distortion is not supported when the number
+        # of axes in WCS is larger than 2. Setting 'degree'
+        # to 1 and 'max_inv_pix_error' to None.
+        hdr, _ = w.to_fits(degree=3)
 
     # check that FITS WCS is not using SIP
     assert not hdr['?_ORDER']
@@ -982,6 +1004,7 @@ def test_to_fits_tab_miri_image():
     hdulist = fits.HDUList(
         [fits.PrimaryHDU(np.ones(w.pixel_n_dim * (2, )), hdr), bt]
     )
+
     fits_wcs = astwcs.WCS(hdulist[0].header, hdulist)
 
     # test points:
@@ -1004,7 +1027,11 @@ def test_to_fits_tab_miri_lrs():
     hdulist = fits.HDUList(
         [fits.PrimaryHDU(np.ones(w.pixel_n_dim * (2, )), hdr), bt[0]]
     )
-    fits_wcs = astwcs.WCS(hdulist[0].header, hdulist)
+    with pytest.warns(astwcs.FITSFixedWarning, match='The WCS transformation has more axes'):
+        # this raises a warning unimportant for this testing the pix2world
+        #   FITSFixedWarning(u'The WCS transformation has more axes (3) than
+        #        the image it is associated with (2)')
+        fits_wcs = astwcs.WCS(hdulist[0].header, hdulist)
 
     # test points:
     (xmin, xmax), (ymin, ymax) = w.bounding_box
@@ -1181,12 +1208,11 @@ def test_tabular_2d_quantity():
     assert all(u.allclose(u.Quantity(b), [0, 2] * u.pix) for b in bb)
 
 
-@pytest.mark.filterwarnings("error:.*Indexing a WCS.pipeline step is deprecated.*:DeprecationWarning")
 def test_initialize_wcs_with_list():
     # test that you can initialize a wcs with a pipeline that is a list
     # containing both Step() and (frame, transform) tuples
 
-    # make pipline consisting of tuples and Steps
+    # make pipeline consisting of tuples and Steps
     shift1 = models.Shift(10 * u .pix) & models.Shift(2 * u.pix)
     shift2 = models.Shift(3 * u.pix)
     pipeline = [('detector', shift1), wcs.Step('extra_step', shift2)]
@@ -1195,4 +1221,6 @@ def test_initialize_wcs_with_list():
     pipeline.append(extra_step)
 
     # make sure no warnings occur when creating wcs with this pipeline
-    wcs.WCS(pipeline)
+    with warnings.catch_warnings():
+        warnings.simplefilter("error")
+        wcs.WCS(pipeline)
